@@ -1,9 +1,9 @@
 import os
 import subprocess
 import sys
-from . import task
+from jobx import jobx
+
 os.environ['ANSI_COLORS_DISABLED']="1"
-import shutil
 import fire
 def _run_command(args):
     return subprocess.check_call(" ".join(args), shell=True)
@@ -22,7 +22,7 @@ class CLI:
         print("executable:", sys.executable)
 
 def main():
-    fire.Fire(task.CLI.tasks)
+    fire.Fire(jobx.CLI.tasks)
 
 if __name__ == '__main__':
     main()
